#### Testing whether protected areas prevent the development of medicinal plant knowledge
# By Dr Kowiyou Yessoufou, University of Johannesburg, South Africa

rm(list=ls(all=TRUE))

library(piecewiseSEM)
library(lmerTest)
library(nlme)
library(lme4)

### Accessing the dataset to be analysed on my laptop
dat.knp <- read.table("C:\\Users\\kowiyouy\\Desktop\\UJ\\PhD students\\Isidore cosupervision with Ramepdi\\data\\availability hypothesis\\data\\availability_final_data_final_final.txt",header=TRUE)
attach(dat.knp)
names(dat.knp)

###create metamodels
## In first metal model, total abundance (abundance inside + outside of KNP) is used 
# Test of availability hypothesis: does total abundance predict medicinal plant status?

mod.list1a=list(
  glm(status_number~abundance_total+recipes,family=binomial,data=dat.knp),
  glm.nb(recipes~abundance_total+total_organ_used,data=dat.knp),
  glm.nb(total_organ_used~abundance_total,data=dat.knp)
)
sem.fit(mod.list1a, dat.knp, .progressBar = FALSE)
(coef.table = sem.coefs(mod.list1a, dat.knp))

#### Results Overall fit:
# fisher.c = 0 (df=2, P=1)
# AIC   AICc  K   n
#  20 20.305 10 732

#    response        predictor          estimate     std.error     p.value    
#    status_number   abundance_total    0.04382630   1.756430e-02  0.0126   *
#    status_number   recipes            25.99200043  1.890794e+03  0.9890    
#    recipes         total_organ_used   2.01780067   8.186201e-02  0.0000 ***
#    recipes         abundance_total    0.01394276   2.869345e-03  0.0000 ***
# total_organ_used  abundance_total     0.02035534   2.142564e-03  0.0000 ***

# Interestingly, total plants' abundance predicts their medicinal status
# This is a support for availability hypothesis


## Next question: does PAs influence the development of medicinal plant knowledge?
# Our theoretical expectation is that plants that are inside PAs are less likely to be medicinal, even if they are abundance inside the park, because
# they are less often in contact with local communities. In contrast, plants that are outside the park are more likley to be medicinal
# because they are in everyday-contact with local communities, particularly plants that are abundant (availability hypothesis). 


### Let's modify metamodel 1b to create another 2 metamodels 1c and 1d in which total abundance is replaced with abundance outside and abundance inside the park, respectively. 

# metamodel 1b
mod.list1c=list(
  glm(status_number~outside+recipes,family=binomial,data=dat.knp),
  glm.nb(recipes~outside+total_organ_used,data=dat.knp),
  glm.nb(total_organ_used~outside,data=dat.knp)
)
sem.fit(mod.list1b, dat.knp, .progressBar = FALSE)
(coef.table = sem.coefs(mod.list1c, dat.knp))

# cResults: fisher.c = 0 (df = 2, p =1)
# AIC   AICc  K   n
# 20 20.305 10 732

#    response          predictor           estimate     std.error     p.value    
#    status_number     outside             0.06791196   2.282250e-02  0.0029  **
#    status_number     recipes             26.31725749  1.868396e+03  0.9888    
#    recipes           total_organ_used    2.04729276   8.180492e-02  0.0000 ***
#    recipes           outside             0.01519750   3.430961e-03  0.0000 ***
#    total_organ_used  outside             0.02327069   2.660211e-03  0.0000 ***

### Lets replace "outside" with "inside" in metamodel 1
#metamodel 1c

mod.list1c=list(
  glm(status_number~inside+recipes,family=binomial,data=dat.knp),
  glm.nb(recipes~inside+total_organ_used,data=dat.knp),
  glm.nb(total_organ_used~inside,data=dat.knp)
)
sem.fit(mod.list1c, dat.knp, .progressBar = FALSE)
(coef.table = sem.coefs(mod.list1c, dat.knp))

# overal fit: fisher.c = 0 (df=2, P=1)
#AIC   AICc  K   n
#  20 20.305 10 732

# models 1c and 1d are equivalent (same AIC value). This is not a suprise given the 
# positive significant correlation between inside and outside abundance (cor=0.27; df=803, p<0.001)
# All results
#  response           predictor         estimate    std.error     p.value    
#  status_number      inside           -0.11380069  1.516137e-01  0.4529    
#  status_number      recipes          26.76422407  1.763382e+03  0.9879    
#  recipes            total_organ_used 2.13166738   8.188124e-02  0.0000 ***
#  recipes            inside           0.02127949   7.903200e-03  0.0071  **
#  total_organ_used   inside           0.03413092   5.943712e-03  0.0000 ***
  
# Please not that "inside" is not a significant predictor of medicinal status. 
# It actually shows that abundant plants inside tend to be non-medicinal(beta=-0.11+/-0.15, P=0.452)



########################

# To test this, we used different scenarios that are modifications of metamodels 1a
# Scenario 1: Let's separate abundance inside and outside KNP and include both of them into a new metamodel (called metamodel 1b) in replacement of "total abundance".

mod.list1d=list(
  glm(status_number~inside+outside+recipes+total_organ_used,family=binomial,data=dat.knp),
  glm.nb(outside~inside,data=dat.knp),
  glm.nb(recipes~outside+inside+total_organ_used,data=dat.knp),
  glm.nb(total_organ_used~recipes+outside,data=dat.knp)
)

sem.fit(mod.list1d, dat.knp, .progressBar = FALSE)

(coef.table = sem.coefs(mod.list1d, dat.knp))

######Results of overal fit of the metamodel 1d:

# the analysis identified organ used~inside as missing path, but with p=0.73, 
#meaning that availability inside the park is not a significant predictor of number of organs used in traditional medicine
# suggesting that the park may be limiting knowledge of plant usages.

#However, when that missing path is included in the metamodel, all endogenous variables become conditionally dependent, and 
# and test of directed separation impossible. We therefore left that missing out of the SEM analysis.
# The overall fit of the metamodel is: Fisher.C = 0.6, df=2 and P=0.739, suggesting the metamodel 
# can be used to explain the determinants of medicinal plant identifications.
# It is critical to also highlight that the abundance of plants inside the park is not a significant predictor of the number of recipes,

# Surprisingly, neither abundance outside the park (beta=0.009+/0.029, P=1.00) nor abundance inside the park (beta=0.07+/-0.08, P=0.99) is a significant predictor of medicinal status.
# So too are number of recipes (beta=41.53+/-0.0001, P=0.99) and total number of organs used (beta=7.39+/-0.0001, P=0.99). 

# All results are (present this as a table in the paper:
#       response        predictor       estimate     std.error    p.value    
# 1     status_number          recipes 41.537807319 1.016577e+04  0.9967    
# 2     status_number total_organ_used  7.393078141 1.760279e+04  0.9997    
# 3     status_number           inside  0.079715291 8.272230e+02  0.9999    
# 4     status_number          outside  0.009248121 2.936291e+02  1.0000    
# 5           outside           inside  0.027053245 5.457774e-03  0.0000 ***
# 6           recipes total_organ_used  2.017545798 8.187900e-02  0.0000 ***
# 7           recipes          outside  0.013770865 3.524788e-03  0.0001 ***
# 8           recipes           inside  0.014608895 7.952195e-03  0.0662    
# 9  total_organ_used          recipes  0.130227250 1.074832e-02  0.0000 ***
# 10 total_organ_used          outside  0.011325640 2.963303e-03  0.0001 ***

